@@ -9,8 +9,6 @@
 
 AbstractModel::AbstractModel(QObject *parent)
     : QAbstractListModel(parent)
-    , m_favoritesModel(nullptr)
-    , m_iconSize(32)
 {
 }
 
