@@ -6,6 +6,8 @@
 
 #include "sessionsmodel.h"
 
+#include <utility>
+
 #include <KAuthorized>
 #include <KLocalizedString>
 #include <KUser>
@@ -40,12 +42,12 @@ SessionsModel::SessionsModel(QObject *parent)
 
 bool SessionsModel::canSwitchUser() const
 {
-    return const_cast<SessionsModel *>(this)->m_displayManager.isSwitchable() && KAuthorized::authorizeAction(QLatin1String("switch_user"));
+    return const_cast<SessionsModel *>(this)->m_displayManager.isSwitchable() && KAuthorized::authorizeAction(QStringLiteral("switch_user"));
 }
 
 bool SessionsModel::canStartNewSession() const
 {
-    return const_cast<SessionsModel *>(this)->m_displayManager.numReserve() > 0 && KAuthorized::authorizeAction(QLatin1String("start_new_session"));
+    return const_cast<SessionsModel *>(this)->m_displayManager.numReserve() > 0 && KAuthorized::authorizeAction(QStringLiteral("start_new_session"));
 }
 
 bool SessionsModel::shouldLock() const
@@ -148,7 +150,7 @@ void SessionsModel::reload()
     m_data.clear();
     m_data.reserve(sessions.count());
 
-    foreach (const SessEnt &session, sessions) {
+    for (const SessEnt &session : std::as_const(sessions)) {
         if (!session.vt || session.self) {
             continue;
         }
