@@ -30,7 +30,6 @@
 #include <QDir>
 #include <QFontDatabase>
 #include <QSettings>
-#include <QTextCodec>
 
 #include <QByteArray>
 #include <QDBusConnection>
@@ -47,13 +46,16 @@
 #include <KLocalizedString>
 #include <KProcess>
 #include <KWindowSystem>
-#include <Kdelibs4Migration>
 
 #include <updatelaunchenvjob.h>
 
 #include "krdb.h"
 #if HAVE_X11
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <X11/Xlib.h>
 #endif
 inline const char *gtkEnvVar(int version)
@@ -249,8 +251,6 @@ static void createGtkrc(const QPalette &cg, bool exportGtkTheme, const QString &
         return;
 
     QTextStream t(&saveFile);
-    t.setCodec(QTextCodec::codecForLocale());
-
     t << i18n(
         "# created by KDE Plasma, %1\n"
         "#\n",
@@ -505,106 +505,4 @@ void runRdb(uint flags)
         }
 #endif
     }
-
-    // Legacy support:
-    // Try to sync kde4 settings with ours
-
-    Kdelibs4Migration migration;
-    // kf5 congig groups for general and icons
-    KConfigGroup generalGroup(kglobalcfg, "General");
-    KConfigGroup iconsGroup(kglobalcfg, "Icons");
-
-    const QString colorSchemeName = generalGroup.readEntry("ColorScheme", QStringLiteral("BreezeLight"));
-
-    QString colorSchemeSrcFile;
-    if (colorSchemeName != QLatin1String("Default")) {
-        // fix filename, copied from ColorsCM::saveScheme()
-        QString colorSchemeFilename = colorSchemeName;
-        colorSchemeFilename.remove('\''); // So Foo's does not become FooS
-        QRegExp fixer(QStringLiteral("[\\W,.-]+(.?)"));
-        int offset;
-        while ((offset = fixer.indexIn(colorSchemeFilename)) >= 0)
-            colorSchemeFilename.replace(offset, fixer.matchedLength(), fixer.cap(1).toUpper());
-        colorSchemeFilename.replace(0, 1, colorSchemeFilename.at(0).toUpper());
-
-        // clone the color scheme
-        colorSchemeSrcFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "color-schemes/" + colorSchemeFilename + ".colors");
-        const QString dest = migration.saveLocation("data", QStringLiteral("color-schemes")) + colorSchemeName + ".colors";
-        QFile::remove(dest);
-        QFile::copy(colorSchemeSrcFile, dest);
-    }
-
-    // Apply the color scheme
-    QString configFilePath = migration.saveLocation("config") + "kdeglobals";
-
-    if (configFilePath.isEmpty()) {
-        return;
-    }
-
-    KConfig kde4config(configFilePath, KConfig::SimpleConfig);
-
-    KConfigGroup kde4generalGroup(&kde4config, "General");
-    kde4generalGroup.writeEntry("ColorScheme", colorSchemeName);
-
-    // fonts
-    QString font = generalGroup.readEntry("font", QString());
-    if (!font.isEmpty()) {
-        kde4generalGroup.writeEntry("font", font);
-    }
-    font = generalGroup.readEntry("desktopFont", QString());
-    if (!font.isEmpty()) {
-        kde4generalGroup.writeEntry("desktopFont", font);
-    }
-    font = generalGroup.readEntry("menuFont", QString());
-    if (!font.isEmpty()) {
-        kde4generalGroup.writeEntry("menuFont", font);
-    }
-    font = generalGroup.readEntry("smallestReadableFont", QString());
-    if (!font.isEmpty()) {
-        kde4generalGroup.writeEntry("smallestReadableFont", font);
-    }
-    font = generalGroup.readEntry("taskbarFont", QString());
-    if (!font.isEmpty()) {
-        kde4generalGroup.writeEntry("taskbarFont", font);
-    }
-    font = generalGroup.readEntry("toolBarFont", QString());
-    if (!font.isEmpty()) {
-        kde4generalGroup.writeEntry("toolBarFont", font);
-    }
-
-    // TODO: does exist any way to check if a qt4 widget style is present from a qt5 app?
-    // kde4generalGroup.writeEntry("widgetStyle", "qtcurve");
-    kde4generalGroup.sync();
-
-    KConfigGroup kde4IconGroup(&kde4config, "Icons");
-    QString iconTheme = iconsGroup.readEntry("Theme", QString());
-    if (!iconTheme.isEmpty()) {
-        kde4IconGroup.writeEntry("Theme", iconTheme);
-    }
-    kde4IconGroup.sync();
-
-    if (!colorSchemeSrcFile.isEmpty()) {
-        // copy all the groups in the color scheme in kdeglobals
-        KSharedConfigPtr kde4ColorConfig = KSharedConfig::openConfig(colorSchemeSrcFile, KConfig::SimpleConfig);
-
-        foreach (const QString &grp, kde4ColorConfig->groupList()) {
-            KConfigGroup cg(kde4ColorConfig, grp);
-            KConfigGroup cg2(&kde4config, grp);
-            cg.copyTo(&cg2);
-        }
-    }
-
-    // widgets settings
-    KConfigGroup kglobals4(&kde4config, "KDE");
-    kglobals4.writeEntry("ShowIconsInMenuItems", kglobals.readEntry("ShowIconsInMenuItems", true));
-    kglobals4.writeEntry("ShowIconsOnPushButtons", kglobals.readEntry("ShowIconsOnPushButtons", true));
-    kglobals4.writeEntry("contrast", kglobals.readEntry("contrast", 4));
-    // FIXME: this should somehow check if the kde4 version of the style is installed
-    kde4generalGroup.writeEntry("widgetStyle", kglobals.readEntry("widgetStyle", "breeze"));
-
-    // toolbar style
-    KConfigGroup toolbars4(&kde4config, "Toolbar style");
-    KConfigGroup toolbars5(kglobalcfg, "Toolbar style");
-    toolbars4.writeEntry("ToolButtonStyle", toolbars5.readEntry("ToolButtonStyle", "TextBesideIcon"));
-    toolbars4.writeEntry("ToolButtonStyleOtherToolbars", toolbars5.readEntry("ToolButtonStyleOtherToolbars", "TextBesideIcon"));
 }
