@@ -28,10 +28,13 @@ private Q_SLOTS:
     void initTestCase();
     void cleanupTestCase();
 
+    void testExcutableExactMatch();
     void testChromeAppsRelevance();
     void testKonsoleVsYakuakeComment();
     void testSystemSettings();
     void testSystemSettings2();
+    void testCategories();
+    void testJumpListActions();
     void testINotifyUsage();
 };
 
@@ -64,6 +67,19 @@ void ServiceRunnerTest::cleanupTestCase()
 {
 }
 
+void ServiceRunnerTest::testExcutableExactMatch()
+{
+    ServiceRunner runner(this, KPluginMetaData(), QVariantList());
+    Plasma::RunnerContext context;
+    context.setQuery(QStringLiteral("Virtual Machine Manager ServiceRunnerTest")); // virt-manager.desktop
+
+    runner.match(context);
+    auto matches = context.matches();
+    QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        return match.text() == QLatin1String("Virtual Machine Manager ServiceRunnerTest") && match.relevance() == 1;
+    }));
+}
+
 void ServiceRunnerTest::testChromeAppsRelevance()
 {
     ServiceRunner runner(this, KPluginMetaData(), QVariantList());
@@ -178,6 +194,62 @@ void ServiceRunnerTest::testSystemSettings2()
     QVERIFY(!foreignSystemSettingsFound);
 }
 
+void ServiceRunnerTest::testCategories()
+{
+    ServiceRunner runner(this, KPluginMetaData(), QVariantList());
+    Plasma::RunnerContext context;
+
+    context.setQuery(QStringLiteral("System"));
+    runner.match(context);
+    auto matches = context.matches();
+    QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        return match.text() == QLatin1String("Konsole ServiceRunnerTest") && match.relevance() == 0.64;
+    }));
+
+    // Multiple categories
+    context.setQuery(QStringLiteral("System KDE TerminalEmulator"));
+    runner.match(context);
+    matches = context.matches();
+    QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        return match.text() == QLatin1String("Konsole ServiceRunnerTest") && match.relevance() == 0.64;
+    }));
+
+    // Multiple categories but at least one doesn't match
+    context.setQuery(QStringLiteral("System KDE Office"));
+    runner.match(context);
+    matches = context.matches();
+    QVERIFY(std::none_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        return match.text() == QLatin1String("Konsole ServiceRunnerTest");
+    }));
+}
+
+void ServiceRunnerTest::testJumpListActions()
+{
+    ServiceRunner runner(this, KPluginMetaData(), QVariantList());
+    Plasma::RunnerContext context;
+
+    context.setQuery(QStringLiteral("open a new window")); // org.kde.konsole.desktop
+    runner.match(context);
+    auto matches = context.matches();
+    QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        return match.text() == QLatin1String("Open a New Window - Konsole ServiceRunnerTest") && match.relevance() == 0.55;
+    }));
+
+    context.setQuery(QStringLiteral("new window"));
+    runner.match(context);
+    matches = context.matches();
+    QVERIFY(std::any_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        return match.text() == QLatin1String("Open a New Window - Konsole ServiceRunnerTest") && match.relevance() == 0.5;
+    }));
+
+    context.setQuery(QStringLiteral("new windows"));
+    runner.match(context);
+    matches = context.matches();
+    QVERIFY(std::none_of(matches.cbegin(), matches.cend(), [](const Plasma::QueryMatch &match) {
+        return match.text() == QLatin1String("Open a New Window - Konsole ServiceRunnerTest");
+    }));
+}
+
 void ServiceRunnerTest::testINotifyUsage()
 {
     auto inotifyCount = []() -> uint {
